<?php

/*
Plugin Name: Country Filter ( MaxMind GeoIPLite )
Plugin URI: http://www.codediesel.com/plugins/country-filter/
Description: Ability to display or hide content depending on the users country of origin.
Version: 1.5.1
Author: Sameer Borate
Author URI: http://www.codediesel.com
*/


/*  
Copyright 2009-2011  Sameer Borate
email: metapix@gmail.com

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE. 

*/

require_once("geoip.inc");

if(!function_exists('codediesel_get_ipaddress')) {
	function codediesel_get_ipaddress() {
		if (empty($_SERVER["HTTP_X_FORWARDED_FOR"])) {
			$ip_address = $_SERVER["REMOTE_ADDR"];
		} else {
			$ip_address = $_SERVER["HTTP_X_FORWARDED_FOR"];
		}
		if(strpos($ip_address, ',') !== false) {
			$ip_address = explode(',', $ip_address);
			$ip_address = $ip_address[0];
		}
		return $ip_address;
	}
}


if(!function_exists('codediesel_get_users_country')) {
    function codediesel_get_users_country() {
        global $wpdb, $cache_ips;
        $geodbfile = WP_PLUGIN_DIR . "/" . dirname ( plugin_basename ( __FILE__ ) ) . "/GeoIP.dat";
        
        if (!isset($cache_ips[$ip])) {
            $ip = codediesel_get_ipaddress();  
            $gi = geoip_open($geodbfile,GEOIP_STANDARD);            
            $cache_ips[$ip] = @strtolower(geoip_country_code_by_addr($gi, $ip));
        }
        return $cache_ips[$ip];
    }
}


if(function_exists('codediesel_get_ipaddress') &&
   function_exists('codediesel_get_users_country') &&
   !function_exists('isCountryInFilter')) {

    function isCountryInFilter($countries) {
        $user_country_code = codediesel_get_users_country();
        
        return (in_array($user_country_code, $countries));
    }
} else {
    exit("This plugin is conflicting with some other installed plugins.");
}


if(function_exists('codediesel_get_ipaddress') &&
   function_exists('codediesel_get_users_country') &&
   !function_exists('showCountryContentInPage')) {

    function showCountryContentInPage($countries, $display = 1) {
        $user_country_code = codediesel_get_users_country();
        
        /* If the user is from one of the countries listed in the 'code' attribute
         * and the 'display' attribute is set to '1' than DISPLAY the content for
         * the given countries, but hide for other.
        */
        if(in_array($user_country_code, $countries) && ($display == 1)) {
            return true;
        }
    
        /* If the user is from one of the countries listed in the 'code' attribute
         * and the 'display' attribute is set to '0' than HIDE the content for that
         * countries, but display for other countries.
        */
        if(in_array($user_country_code, $countries) && ($display == 0)) {
            return false;
        } elseif(!in_array($user_country_code, $countries) && ($display == 0)) {
            return true;
        }
        
    }
} else {
    exit("This plugin is conflicting with some other installed plugins.");
}



if(function_exists('codediesel_get_ipaddress') &&
   function_exists('codediesel_get_users_country') &&
   !function_exists('showCountryContent')) {
    
    function showCountryContent($params, $content = null)
    {
        /* Return the original content if no 'country code' or 'display' attributes is specified */
        if(!isset($params['code']) || !isset($params['display'])) {
            return $content;
        }
    
        /* Remove any spaces between country codes */
        $ccode = str_replace(" ", "", $params['code']);
        
        /* Get the country code in an array */
        $countries = explode(",", $ccode);
        $user_country_code = codediesel_get_users_country();
        
        /* If the user is from one of the countries listed in the 'code' attribute
         * and the 'display' attribute is set to '1' than DISPLAY the content for
         * the given countries, but hide for other.
        */
        if(in_array($user_country_code, $countries) && ($params['display'] == 1)) {
            /* process any nested short codes */ 
	 	    return do_shortcode($content); 
        }
    
        /* If the user is from one of the countries listed in the 'code' attribute
         * and the 'display' attribute is set to '0' than HIDE the content for that
         * countries, but display for other countries.
        */
        if(in_array($user_country_code, $countries) && ($params['display'] == 0)) {
            return "";
        } elseif(!in_array($user_country_code, $countries) && ($params['display'] == 0)) {
            /* process any nested short codes */ 
	 	    return do_shortcode($content); 
        }
    
    }
} else {
    exit("This plugin is conflicting with some other installed plugins.");
}


add_shortcode('country-filter', 'showCountryContent');

?>